@@ -540,7 +540,8 @@ using namespace Exiv2::Internal;
 
 QuickTimeVideo::QuickTimeVideo(BasicIo::UniquePtr io, size_t max_recursion_depth) :
     Image(ImageType::qtime, mdNone, std::move(io)),
-    timeScale_(1),
+    mvhdTimeScale_(1),
+    mdhdTimeScale_(1),
     currentStream_(Null),
     max_recursion_depth_(max_recursion_depth) {
 }  // QuickTimeVideo::QuickTimeVideo
@@ -685,6 +686,8 @@ void QuickTimeVideo::tagDecoder(Exiv2::DataBuf& buf, size_t size, size_t recursi
       xmpData_["Xmp.video.URL"] = readString(*io_, size);
     else if (currentStream_ == Audio)
       xmpData_["Xmp.audio.URL"] = readString(*io_, size);
+    else
+      discard(size);
   }
 
   else if (equalsQTimeTag(buf, "urn ")) {
@@ -692,6 +695,8 @@ void QuickTimeVideo::tagDecoder(Exiv2::DataBuf& buf, size_t size, size_t recursi
       xmpData_["Xmp.video.URN"] = readString(*io_, size);
     else if (currentStream_ == Audio)
       xmpData_["Xmp.audio.URN"] = readString(*io_, size);
+    else
+      discard(size);
   }
 
   else if (equalsQTimeTag(buf, "dcom")) {
@@ -1166,7 +1171,7 @@ void QuickTimeVideo::timeToSampleDecoder() {
   }
   if (currentStream_ == Video)
     xmpData_["Xmp.video.FrameRate"] =
-        static_cast<double>(totalframes) * static_cast<double>(timeScale_) / static_cast<double>(timeOfFrames);
+        static_cast<double>(totalframes) * static_cast<double>(mdhdTimeScale_) / static_cast<double>(timeOfFrames);
 }  // QuickTimeVideo::timeToSampleDecoder
 
 void QuickTimeVideo::sampleDesc(size_t size) {
@@ -1432,6 +1437,7 @@ void QuickTimeVideo::mediaHeaderDecoder(size_t size) {
         time_scale = buf.read_uint32(0, bigEndian);
         if (time_scale <= 0)
           time_scale = 1;
+        mdhdTimeScale_ = time_scale;
         break;
       case MediaDuration:
         if (currentStream_ == Video)
@@ -1491,9 +1497,9 @@ void QuickTimeVideo::trackHeaderDecoder(size_t size) {
         break;
       case TrackDuration:
         if (currentStream_ == Video)
-          xmpData_["Xmp.video.TrackDuration"] = timeScale_ ? buf.read_uint32(0, bigEndian) / timeScale_ : 0;
+          xmpData_["Xmp.video.TrackDuration"] = mvhdTimeScale_ ? buf.read_uint32(0, bigEndian) / mvhdTimeScale_ : 0;
         else if (currentStream_ == Audio)
-          xmpData_["Xmp.audio.TrackDuration"] = timeScale_ ? buf.read_uint32(0, bigEndian) / timeScale_ : 0;
+          xmpData_["Xmp.audio.TrackDuration"] = mvhdTimeScale_ ? buf.read_uint32(0, bigEndian) / mvhdTimeScale_ : 0;
         break;
       case TrackLayer:
         if (currentStream_ == Video)
@@ -1550,13 +1556,13 @@ void QuickTimeVideo::movieHeaderDecoder(size_t size) {
         break;
       case TimeScale:
         xmpData_["Xmp.video.TimeScale"] = buf.read_uint32(0, bigEndian);
-        timeScale_ = buf.read_uint32(0, bigEndian);
-        if (timeScale_ <= 0)
-          timeScale_ = 1;
+        mvhdTimeScale_ = buf.read_uint32(0, bigEndian);
+        if (mvhdTimeScale_ <= 0)
+          mvhdTimeScale_ = 1;
         break;
       case Duration:
-        if (timeScale_ != 0) {  // To prevent division by zero
-          xmpData_["Xmp.video.Duration"] = buf.read_uint32(0, bigEndian) * 1000 / timeScale_;
+        if (mvhdTimeScale_ != 0) {  // To prevent division by zero
+          xmpData_["Xmp.video.Duration"] = buf.read_uint32(0, bigEndian) * 1000 / mvhdTimeScale_;
         }
         break;
       case PreferredRate:
