@@ -51,5 +51,5 @@ TEST(RiffVideo, readMetadata) {
   ASSERT_NO_THROW(riff.setXmpData(xmpData));
   auto data = riff.xmpData();
   ASSERT_FALSE(data.empty());
-  ASSERT_EQ(xmpData["Xmp.video.TotalStream"].count(), 4);
+  ASSERT_EQ(xmpData["Xmp.video.TotalStream"].count(), 4u);
 }
